autowisp.fit_expression.FitTermsParser module — AutoWISP documentation

# autowisp.fit_expression.FitTermsParser module

## Class Inheritance Diagram

class autowisp.fit_expression.FitTermsParser.FitTermsParser(input: ~antlr4.BufferedTokenStream.TokenStream, output: ~typing.TextIO = <_io.TextIOWrapper name='<stdout>' mode='w' encoding='utf-8'>)

  Bases: `Parser`

  CROSSPRODUCT = 4
  EOF = -1
  class Fit_polynomialContext(parser, parent: ParserRuleContext = None, invokingState: int = -1)

    Bases: `ParserRuleContext`

    POLY_START()
    UINT()
    accept(visitor: ParseTreeVisitor)
    enterRule(listener: ParseTreeListener)
    exitRule(listener: ParseTreeListener)
    fit_terms_list()
    getRuleIndex()
    parser
  class Fit_termContext(parser, parent: ParserRuleContext = None, invokingState: int = -1)

    Bases: `ParserRuleContext`

    TERM()
    accept(visitor: ParseTreeVisitor)
    enterRule(listener: ParseTreeListener)
    exitRule(listener: ParseTreeListener)
    getRuleIndex()
    parser
  class Fit_terms_expressionContext(parser, parent: ParserRuleContext = None, invokingState: int = -1)

    Bases: `ParserRuleContext`

    UNION(i: int = None)
    accept(visitor: ParseTreeVisitor)
    enterRule(listener: ParseTreeListener)
    exitRule(listener: ParseTreeListener)
    fit_terms_set_cross_product(i: int = None)
    getRuleIndex()
    parser
  class Fit_terms_listContext(parser, parent: ParserRuleContext = None, invokingState: int = -1)

    Bases: `ParserRuleContext`

    TERM_LIST_END()
    TERM_LIST_START()
    TERM_SEP(i: int = None)
    accept(visitor: ParseTreeVisitor)
    enterRule(listener: ParseTreeListener)
    exitRule(listener: ParseTreeListener)
    fit_term(i: int = None)
    getRuleIndex()
    parser
  class Fit_terms_setContext(parser, parent: ParserRuleContext = None, invokingState: int = -1)

    Bases: `ParserRuleContext`

    accept(visitor: ParseTreeVisitor)
    enterRule(listener: ParseTreeListener)
    exitRule(listener: ParseTreeListener)
    fit_polynomial()
    fit_terms_list()
    getRuleIndex()
    parser
  class Fit_terms_set_cross_productContext(parser, parent: ParserRuleContext = None, invokingState: int = -1)

    Bases: `ParserRuleContext`

    CROSSPRODUCT(i: int = None)
    accept(visitor: ParseTreeVisitor)
    enterRule(listener: ParseTreeListener)
    exitRule(listener: ParseTreeListener)
    fit_terms_set(i: int = None)
    getRuleIndex()
    parser
  POLY_START = 3
  RULE_fit_polynomial = 2
  RULE_fit_term = 0
  RULE_fit_terms_expression = 5
  RULE_fit_terms_list = 1
  RULE_fit_terms_set = 3
  RULE_fit_terms_set_cross_product = 4
  TERM = 9
  TERM_LIST_END = 7
  TERM_LIST_START = 1
  TERM_SEP = 8
  UINT = 2
  UNION = 5
  WS = 6
  atn = <antlr4.atn.ATN.ATN object>
  buildParseTrees
  decisionsToDFA = [<antlr4.dfa.DFA.DFA object>, <antlr4.dfa.DFA.DFA object>, <antlr4.dfa.DFA.DFA object>, <antlr4.dfa.DFA.DFA object>]
  fit_polynomial()
  fit_term()
  fit_terms_expression()
  fit_terms_list()
  fit_terms_set()
  fit_terms_set_cross_product()
  grammarFileName = 'FitTermsParser.g4'
  literalNames = ['<INVALID>', "'{'", '<INVALID>', "'O'", "'*'", "'+'", '<INVALID>', "'}'", "','"]
  ruleNames = ['fit_term', 'fit_terms_list', 'fit_polynomial', 'fit_terms_set', 'fit_terms_set_cross_product', 'fit_terms_expression']
  sharedContextCache = <antlr4.PredictionContext.PredictionContextCache object>
  symbolicNames = ['<INVALID>', 'TERM_LIST_START', 'UINT', 'POLY_START', 'CROSSPRODUCT', 'UNION', 'WS', 'TERM_LIST_END', 'TERM_SEP', 'TERM']

autowisp.fit_expression.FitTermsParser.serializedATN()